@@ -2,17 +2,15 @@
 {-# LANGUAGE ScopedTypeVariables #-}
 
 module Test.Validity.Relations.Symmetry
-    ( symmetricOnElems
-    , symmetryOnGens
-    , symmetryOnValid
-    , symmetry
-    , symmetryOnArbitrary
-    ) where
+  ( symmetricOnElems,
+    symmetryOnGens,
+    symmetry,
+    symmetryOnArbitrary,
+  )
+where
 
 import Data.GenValidity
-
 import Test.QuickCheck
-
 import Test.Validity.Property.Utils
 
 -- |
@@ -23,30 +21,25 @@ import Test.Validity.Property.Utils
 --   \forall a, b: (a \prec b) \Leftrightarrow (b \prec a)
 -- \]
 symmetricOnElems ::
-       (a -> a -> Bool) -- ^ A relation
-    -> a
-    -> a -- ^ Two elements
-    -> Bool
+  -- | A relation
+  (a -> a -> Bool) ->
+  a ->
+  -- | Two elements
+  a ->
+  Bool
 symmetricOnElems func a b = func a b <==> func b a
 
 symmetryOnGens ::
-       Show a => (a -> a -> Bool) -> Gen (a, a) -> (a -> [a]) -> Property
+  Show a => (a -> a -> Bool) -> Gen (a, a) -> (a -> [a]) -> Property
 symmetryOnGens func gen s =
-    forAllShrink gen (shrinkT2 s) $ uncurry $ symmetricOnElems func
-
--- |
---
--- prop> symmetryOnValid ((==) :: Double -> Double -> Bool)
--- prop> symmetryOnValid ((/=) :: Double -> Double -> Bool)
-symmetryOnValid :: (Show a, GenValid a) => (a -> a -> Bool) -> Property
-symmetryOnValid func = symmetryOnGens func genValid shrinkValid
+  forAllShrink gen (shrinkT2 s) $ uncurry $ symmetricOnElems func
 
 -- |
 --
 -- prop> symmetry ((==) :: Int -> Int -> Bool)
 -- prop> symmetry ((/=) :: Int -> Int -> Bool)
-symmetry :: (Show a, GenUnchecked a) => (a -> a -> Bool) -> Property
-symmetry func = symmetryOnGens func genUnchecked shrinkUnchecked
+symmetry :: (Show a, GenValid a) => (a -> a -> Bool) -> Property
+symmetry func = symmetryOnGens func genValid shrinkValid
 
 -- |
 --
