@@ -2,17 +2,15 @@
 {-# LANGUAGE ScopedTypeVariables #-}
 
 module Test.Validity.Relations.Transitivity
-    ( transitiveOnElems
-    , transitivityOnGens
-    , transitivityOnValid
-    , transitivity
-    , transitivityOnArbitrary
-    ) where
+  ( transitiveOnElems,
+    transitivityOnGens,
+    transitivity,
+    transitivityOnArbitrary,
+  )
+where
 
 import Data.GenValidity
-
 import Test.QuickCheck
-
 import Test.Validity.Property.Utils
 
 -- |
@@ -23,30 +21,19 @@ import Test.Validity.Property.Utils
 --   \forall a, b, c: ((a \prec b) \wedge (b \prec c)) \Rightarrow (a \prec c)
 -- \]
 transitiveOnElems ::
-       (a -> a -> Bool) -- ^ A relation
-    -> a
-    -> a
-    -> a -- ^ Three elements
-    -> Bool
+  -- | A relation
+  (a -> a -> Bool) ->
+  a ->
+  a ->
+  -- | Three elements
+  a ->
+  Bool
 transitiveOnElems func a b c = (func a b && func b c) ===> func a c
 
 transitivityOnGens ::
-       Show a => (a -> a -> Bool) -> Gen (a, a, a) -> (a -> [a]) -> Property
+  Show a => (a -> a -> Bool) -> Gen (a, a, a) -> (a -> [a]) -> Property
 transitivityOnGens func gen s =
-    forAllShrink gen (shrinkT3 s) $ \(a, b, c) -> transitiveOnElems func a b c
-
--- |
---
--- prop> transitivityOnValid ((>) :: Double -> Double -> Bool)
--- prop> transitivityOnValid ((>=) :: Double -> Double -> Bool)
--- prop> transitivityOnValid ((==) :: Double -> Double -> Bool)
--- prop> transitivityOnValid ((<=) :: Double -> Double -> Bool)
--- prop> transitivityOnValid ((<) :: Double -> Double -> Bool)
--- prop> transitivityOnValid (Data.List.isPrefixOf :: [Double] -> [Double] -> Bool)
--- prop> transitivityOnValid (Data.List.isSuffixOf :: [Double] -> [Double] -> Bool)
--- prop> transitivityOnValid (Data.List.isInfixOf :: [Double] -> [Double] -> Bool)
-transitivityOnValid :: (Show a, GenValid a) => (a -> a -> Bool) -> Property
-transitivityOnValid func = transitivityOnGens func genValid shrinkValid
+  forAllShrink gen (shrinkT3 s) $ \(a, b, c) -> transitiveOnElems func a b c
 
 -- |
 --
@@ -58,8 +45,8 @@ transitivityOnValid func = transitivityOnGens func genValid shrinkValid
 -- prop> transitivity (Data.List.isPrefixOf :: [Int] -> [Int] -> Bool)
 -- prop> transitivity (Data.List.isSuffixOf :: [Int] -> [Int] -> Bool)
 -- prop> transitivity (Data.List.isInfixOf :: [Int] -> [Int] -> Bool)
-transitivity :: (Show a, GenUnchecked a) => (a -> a -> Bool) -> Property
-transitivity func = transitivityOnGens func genUnchecked shrinkUnchecked
+transitivity :: (Show a, GenValid a) => (a -> a -> Bool) -> Property
+transitivity func = transitivityOnGens func genValid shrinkValid
 
 -- |
 --
